@@ -5,7 +5,7 @@ use utf8;
 
 package Dist::Zilla::PluginBundle::Author::RTHOMPSON;
 {
-  $Dist::Zilla::PluginBundle::Author::RTHOMPSON::VERSION = '0.132960';
+  $Dist::Zilla::PluginBundle::Author::RTHOMPSON::VERSION = '0.133030';
 }
 # ABSTRACT: RTHOMPSON's Dist::Zilla Configuration
 
@@ -172,7 +172,6 @@ sub configure {
         # Release
         'NextRelease',
         'TestRelease',
-        'ConfirmRelease',
     );
 
     # Choose version control. This must be after 'NextRelease' so that
@@ -211,17 +210,18 @@ sub configure {
                     );
                 }
             }
-
-            if ($args{no_push}) {
-                delete $args{push_to};
-            }
-            if ($args{push_to}) {
-            }
         }
         else {
             croak "Unknown vcs: $_\nTry setting vcs = 'none' and setting it up yourself.";
         }
     }
+
+    # This is added last so that the user is only asked for
+    # confimation if *all* other pre-release checkpoints have been
+    # passed.
+    $self->add_plugins(
+        'ConfirmRelease',
+    );
 }
 
 1; # Magic true value required at end of module
@@ -236,7 +236,7 @@ Dist::Zilla::PluginBundle::Author::RTHOMPSON - RTHOMPSON's Dist::Zilla Configura
 
 =head1 VERSION
 
-version 0.132960
+version 0.133030
 
 =head1 SYNOPSIS
 
